@@ -140,6 +140,7 @@ class Pipe(EntityBase):
                       is_last=None,
                       is_first=None,
                       completeness=None,
+                      headers=None,
                       **kwargs
                       ):
         """This posts the specified entities to the pipe. This only works for pipes that has a source
@@ -178,7 +179,8 @@ class Pipe(EntityBase):
         if is_first is not None:
             params["is_first"] = is_first
 
-        headers = {"Content-Type": "application/json"}
+        if headers is None:
+            headers = {"Content-Type": "application/json"}
         if completeness is not None:
             headers["X-Dataset-Completeness"] = str(completeness)
         response = self._connection.do_post_request(url,
@@ -246,10 +248,14 @@ class Pipe(EntityBase):
                     f"self._raw_jsondata: {textwrap.indent(pprint.pformat(self._raw_jsondata), prefix='    ')}")
             time.sleep(1)
 
-    def preview(self, pipe_config, source_entity):
+    def preview(self, pipe_config, source_entity, do_transit_decoding=True):
         response = self._connection.do_post_request(self._connection.get_pipe_url(self.id) + "/preview",
                                                     allowable_response_status_codes=[200],
                                                     data={
                                                         "pipe-config": json.dumps(pipe_config),
-                                                        "source": json.dumps(source_entity)})
-        return response.json()
+                                                        "source": json.dumps(source_entity)},
+                                                    stream=True)
+        result = list(entity_json.parse_json_stream(response.raw, do_transit_decoding=do_transit_decoding))
+        assert len(result) == 1
+        result = result[0]
+        return result
